@@ -34,6 +34,8 @@ class FixtureTcpWSGIServer(server.TcpWSGIServer):
     """A version of TcpWSGIServer that relays back what it's bound to.
     """
 
+    family = socket.AF_INET # Testing
+
     def __init__(self, application, queue, **kw): # pragma: no cover
         # Coverage doesn't see this as it's ran in a separate process.
         kw['port'] = 0 # Bind to any available port.
@@ -153,7 +155,7 @@ class EchoTests(object):
         self.assertTrue(headers.get('date'))
 
     def test_bad_host_header(self):
-        # http://corte.si/posts/code/pathod/pythonservers/index.html
+        # https://corte.si/posts/code/pathod/pythonservers/index.html
         to_send = ("GET / HTTP/1.0\n"
                    " Host: 0\n\n")
         to_send = tobytes(to_send)
@@ -1386,6 +1388,8 @@ if hasattr(socket, 'AF_UNIX'):
         """A version of UnixWSGIServer that relays back what it's bound to.
         """
 
+        family = socket.AF_UNIX # Testing
+
         def __init__(self, application, queue, **kw): # pragma: no cover
             # Coverage doesn't see this as it's ran in a separate process.
             # To permit parallel testing, use a PID-dependent socket.
